@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.24"
+#define SHISHI_VERSION "0.0.25"
 
 /* Error codes */
 typedef enum
@@ -715,8 +715,8 @@ extern int shishi_ticket_get_enc_part_etype (Shishi * handle,
 					     Shishi_asn1 ticket,
 					     int32_t * etype);
 extern int shishi_ticket_set_enc_part (Shishi * handle, Shishi_asn1 ticket,
-				       int etype, int kvno,
-				       char *buf, size_t buflen);
+				       int32_t etype, uint32_t kvno,
+				       const char *buf, size_t buflen);
 extern int shishi_ticket_add_enc_part (Shishi * handle, Shishi_asn1 ticket,
 				       Shishi_key * key,
 				       Shishi_asn1 encticketpart);
@@ -1234,7 +1234,7 @@ extern int shishi_kdcrep_crealmserver_set (Shishi * handle,
 					   const char *crealm,
 					   const char *client);
 extern int shishi_kdcrep_set_enc_part (Shishi * handle, Shishi_asn1 kdcrep,
-				       int etype, int kvno,
+				       int32_t etype, uint32_t kvno,
 				       const char *buf, size_t buflen);
 extern int shishi_kdcrep_decrypt (Shishi * handle,
 				  Shishi_asn1 kdcrep,
@@ -1812,8 +1812,8 @@ extern char *shishi_key_value (Shishi_key * key);
 extern void shishi_key_value_set (Shishi_key * key, const char *value);
 extern const char *shishi_key_name (Shishi_key * key);
 extern size_t shishi_key_length (Shishi_key * key);
-extern int shishi_key_version (Shishi_key * key);
-extern void shishi_key_version_set (Shishi_key * key, int version);
+extern uint32_t shishi_key_version (Shishi_key * key);
+extern void shishi_key_version_set (Shishi_key * key, uint32_t kvno);
 extern int shishi_key (Shishi * handle, Shishi_key ** key);
 extern void shishi_key_done (Shishi_key * key);
 extern void shishi_key_copy (Shishi_key * dstkey, Shishi_key * srckey);
@@ -1934,7 +1934,7 @@ extern int shishi_apreq_save (Shishi * handle, FILE * fh, Shishi_asn1 apreq);
 extern int shishi_apreq_set_ticket (Shishi * handle, Shishi_asn1 apreq,
 				    Shishi_asn1 ticket);
 extern int shishi_apreq_set_authenticator (Shishi * handle, Shishi_asn1 apreq,
-					   int32_t etype,
+					   int32_t etype, uint32_t kvno,
 					   const char *buf, size_t buflen);
 extern int shishi_apreq_add_authenticator (Shishi * handle, Shishi_asn1 apreq,
 					   Shishi_key * key, int keyusage,
